@@ -121,7 +121,11 @@ SambaUserSharePlugin::SambaUserSharePlugin(QObject *parent, const QList<QVariant
     connect(propertiesUi.sambaChk, SIGNAL(toggled(bool)), this, SIGNAL(changed()));
     connect(propertiesUi.sambaNameEdit, SIGNAL(textChanged(QString)), this, SIGNAL(changed()));
     connect(propertiesUi.sambaNameEdit, SIGNAL(textChanged(QString)), this, SLOT(checkShareName(QString)));
-    connect(propertiesUi.sambaAllowGuestChk, SIGNAL(toggled(bool)), this, SIGNAL(changed()));
+    connect(propertiesUi.sambaAllowGuestChk, &QCheckBox::toggled,
+            this, [=] (bool checked) {
+                propertiesUi.tableView->setEnabled(checked && propertiesUi.sambaChk->isChecked());
+                setDirty();
+            });
     connect(model, SIGNAL(dataChanged(QModelIndex,QModelIndex)), this, SIGNAL(changed()));
 
     for (int i = 0; i < model->rowCount(); ++i) {
@@ -192,6 +196,7 @@ void SambaUserSharePlugin::setupViews()
     propertiesUi.tableView->setModel(model);
     propertiesUi.tableView->setSelectionMode(QAbstractItemView::NoSelection);
     propertiesUi.tableView->setItemDelegate(new UserPermissionDelegate(this));
+    propertiesUi.tableView->horizontalHeader()->setSectionResizeMode(1, QHeaderView::Stretch);
 }
 
 void SambaUserSharePlugin::load()
@@ -205,6 +210,8 @@ void SambaUserSharePlugin::load()
         guestAllowed = (bool) shareData.guestPermission();
     }
     propertiesUi.sambaAllowGuestChk->setChecked(guestAllowed);
+    propertiesUi.tableView->setEnabled(propertiesUi.sambaChk->isChecked() &&
+                                       propertiesUi.sambaAllowGuestChk->isChecked());
 
     propertiesUi.sambaNameEdit->setText(shareData.name());
 }
@@ -237,16 +244,24 @@ void SambaUserSharePlugin::applyChanges()
 
 void SambaUserSharePlugin::toggleShareStatus(bool checked)
 {
+    propertiesUi.textLabel1->setEnabled(checked);
     propertiesUi.sambaNameEdit->setEnabled(checked);
-    propertiesUi.sambaAllowGuestChk->setCheckable(checked);
-    propertiesUi.tableView->setEnabled(checked);
+    propertiesUi.sambaAllowGuestChk->setEnabled(checked);
+    propertiesUi.tableView->setEnabled(checked && propertiesUi.sambaAllowGuestChk->isChecked());
     if (checked && propertiesUi.sambaNameEdit->text().isEmpty()) {
         propertiesUi.sambaNameEdit->setText(getNewShareName());
+    } else {
+        propertiesUi.sambaNameEdit->setText(QString());
     }
 }
 
 void SambaUserSharePlugin::checkShareName(const QString &name)
 {
+    // Don't ever disable the OK button when the user is trying to remove a share
+    if (!propertiesUi.sambaChk->isChecked()) {
+        return;
+    }
+
     bool disableButton = false;
 
     if (name.isEmpty()) {
